# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-15 03:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0002_auto_20171212_0058'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='image',
            field=models.ImageField(upload_to=b'hx_toolkit_images'),
        ),
        migrations.AlterField(
            model_name='article',
            name='quarter',
            field=models.CharField(blank=True, choices=[(b'autumn', b'Autumn'), (b'winter', b'Winter'), (b'spring', b'Spring'), (b'summer', b'Summer')], max_length=6, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-12 00:58
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='relatedarticle',
            name='parent_article',
        ),
        migrations.RemoveField(
            model_name='relatedarticle',
            name='related_article',
        ),
        migrations.DeleteModel(
            name='RelatedArticle',
        ),
    ]



from django.contrib import admin
from .models import Article, Category, ResourceLink


class ArticleAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title",)}


class CategoryAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title",)}


admin.site.register(Article, ArticleAdmin)
admin.site.register(Category, CategoryAdmin)
admin.site.register(ResourceLink)
